import { AccessInfo } from '../auth';
declare type ModelBrowseArgs = {
    pagination?: ModelBrowsePagination;
    select?: any;
    where?: any;
    orderBy?: any;
    distinct?: any;
    take?: number;
    skip?: number;
    options?: ModelBrowseOptions;
};
export declare type ModelMiddlewareParams = {
    model?: string;
    action: string;
    args: any;
    dataPath: string[];
    runInTransaction: boolean;
};
export declare type ModelBatchPayload = {
    count: number;
};
export declare type ModelErrorHandler = (error: TypeError, params: ModelMiddlewareParams, accessInfo: AccessInfo) => never;
export interface ModelBrowsePagination {
    pageSize?: number;
    page?: number;
}
export declare type ModelBrowseOptions = {
    speedMode?: boolean;
};
export declare type ModelBrowseReturn<T> = {
    items: T[];
    properties: ModelBrowsePagination | {
        count: number;
    };
};
export declare class ModelMiddleware<T, PrismaClient, ModelClient, CustomCreateArgs, CustomCreateManyArgs, CustomUpdateArgs, CustomUpdateManyArgs, CustomUpsertArgs, CustomBrowseArgs extends ModelBrowseArgs> {
    readonly client: PrismaClient;
    readonly model: ModelClient;
    protected readonly accessInfo: AccessInfo;
    constructor(client: PrismaClient, model: string, accessInfo: AccessInfo, errorHandler?: ModelErrorHandler);
    private packCreateArgs;
    private packUpdateArgs;
    private packUpsertArgs;
    create(params: CustomCreateArgs): Promise<T>;
    createMany(params: CustomCreateManyArgs): Promise<ModelBatchPayload>;
    update(params: CustomUpdateArgs): Promise<T>;
    updateMany(params: CustomUpdateManyArgs): Promise<ModelBatchPayload>;
    upsert(params: CustomUpsertArgs): Promise<T>;
    browse(params: CustomBrowseArgs): Promise<ModelBrowseReturn<T>>;
}
export {};
